Module wasm_bindgen_test_runner

Module wasm_bindgen_test_runner 

A “wrapper binary” used to execute Wasm files as tests

This binary is intended to be used as a “test runner” for Wasm binaries, being compatible with cargo test for the Wasm target. It will automatically execute wasm-bindgen (or the equivalent thereof) and then execute either Node.js over the tests or start a server which a browser can be used to run against to execute tests. In a browser mode if CI is in the environment then it’ll also attempt headless testing, spawning the server in the background and then using the WebDriver protocol to execute tests.

For more documentation about this see the wasm-bindgen-test crate README and source code.

Functions

run_cli_with_args